@@ -6,7 +6,6 @@ import re
 from StringIO import StringIO
 from Scanning import PyrexScanner, StringSourceDescriptor
 from Symtab import ModuleScope
-import Symtab
 import PyrexTypes
 from Visitor import VisitorTransform
 from Nodes import Node, StatListNode
@@ -27,12 +26,12 @@ class StringParseContext(Main.Context):
         self.module_name = name
 
     def find_module(self, module_name, relative_to = None, pos = None, need_pxd = 1):
-        if module_name != self.module_name:
+        if module_name not in (self.module_name, 'cython'):
             raise AssertionError("Not yet supporting any cimports/includes from string code snippets")
         return ModuleScope(module_name, parent_module = None, context = self)
 
 def parse_from_strings(name, code, pxds={}, level=None, initial_pos=None,
-                       context=None):
+                       context=None, allow_struct_enum_decorator=False):
     """
     Utility method to parse a (unicode) string of code. This is mostly
     used for internal Cython compiler purposes (creating code snippets
@@ -66,12 +65,15 @@ def parse_from_strings(name, code, pxds={}, level=None, initial_pos=None,
 
     scanner = PyrexScanner(buf, code_source, source_encoding = encoding,
                      scope = scope, context = context, initial_pos = initial_pos)
+    ctx = Parsing.Ctx(allow_struct_enum_decorator=allow_struct_enum_decorator)
+
     if level is None:
-        tree = Parsing.p_module(scanner, 0, module_name)
+        tree = Parsing.p_module(scanner, 0, module_name, ctx=ctx)
         tree.scope = scope
         tree.is_pxd = False
     else:
-        tree = Parsing.p_code(scanner, level=level)
+        tree = Parsing.p_code(scanner, level=level, ctx=ctx)
+
     tree.scope = scope
     return tree
 
@@ -229,6 +231,12 @@ class TreeFragment(object):
                                    substitutions = nodes,
                                    temps = self.temps + temps, pos = pos)
 
+class SetPosTransform(VisitorTransform):
+    def __init__(self, pos):
+        super(SetPosTransform, self).__init__()
+        self.pos = pos
 
-
-
+    def visit_Node(self, node):
+        node.pos = self.pos
+        self.visitchildren(node)
+        return node
